### Opciones avanzadas

Esta sección está destinada a usuarios avanzados de este software. Aquí puedes encontrar:

1. [**Opciones avanzadas**](./opciones-avanzadas.md)
<br>
En esta sección, puedes explorar cómo especificar idiomas de origen/destino, cambiar servicios de traducción y más.

2. [**Código de idioma**](./Códigos-de-idioma.md)
<br>
Si no estás seguro de qué códigos usar para traducir tus idiomas de origen/destino, puedes encontrarlos aquí.

3. [**Documentación de servicios de traducción**](./Documentación-de-servicios-de-traducción.md)
<br>
Si necesitas revisar la documentación proporcionada por los servicios de traducción que estás utilizando, consulta esta página.

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>